% Truss Solver
%Read in data from a users truss data file
[J B F R] = trussdata1;

njoints = length(J(:,1)); %number of joints
nbars   = length(B(:,1)); %number of bars
nloads  = length(F(:,1)); %number of loads
nreacts = length(R(:,1)); %number of reactions
if (nbars+nreacts) ~= 2*njoints
    disp('Number of equations not equal number of unkowns!')
    return %Stops the function from running
end 

basex = J(B(:,2),2);    basey = J(B(:,2),3);
tipx  = J(B(:,3),2);    tipy  = J(B(:,3),3);


% Find the direction cosines of the bars
x  =  tipx - basex;      y  =  tipy - basey;
D  =  sqrt(x.^2 + y.^2);
cx =  x./D;              cy = y./D; % Direction cosines

A  = zeros(2*njoints);   L  = zeros(2*njoints,1);

for i=1:nbars   %once through for each bar
   A(2*B(i,2)-1  , i ) =  cx(i);
   A(2*B(i,2)    , i ) =  cy(i);
   A(2*B(i,3)-1  , i ) = -cx(i);
   A(2*B(i,3)    , i ) = -cy(i);
end

for j = 1:nreacts %once through for each reaction
    A(2*R(j,2)-1, nbars+j ) = R(j,3);
    A(2*R(j,2)  , nbars+j ) = R(j,4);
end

for k = 1:nloads % once through for each load
    L(2*F(k,1)-1) = -F(k,2);
    L(2*F(k,1)  ) = -F(k,3);
end

T=A\L; %THIS IS THE CALCULATION


%%%%%%OUTPUT%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
drawtruss(J, B, F, R)
fprintf('\n**********************************************\n')
disp('Force units determined by applied loads.')
for i = 1:nbars  %Print bar tensions
    disp([ 'Tension in bar ' num2str(i)...
          '  is:  '          num2str(T(i))  ])
end

for i = 1:nreacts %Print reaction forces
    disp(['Reaction '        num2str(i) ...
          ' at joint '       num2str(J(R(i,2))) ...
          ' in ['            num2str(R(i,3:4)) ...
          '] direction is: ' num2str(T(i+nbars))])
end

disp(['Calculation complete at:'  datestr(now)])
disp('**********************************************')

